@@ -950,7 +950,7 @@ MONGOCTL_PARSER_DEF = {
                     "displayName": "TARGET",
                     "type" : "positional",
                     "nargs": 1,
-                    "help": "database addresse or dbpath. Check docs for"
+                    "help": "database address or dbpath. Check docs for"
                             " more details."
                 },
                     {
@@ -963,6 +963,17 @@ MONGOCTL_PARSER_DEF = {
                     ],
                     "nargs": 0
                 },
+                #   {
+                #    "name": "maxReplLag",
+                #    "type" : "optional",
+                #    "help": "Used only with --use-best-secondary. Select "
+                #            "members whose repl lag is less than than "
+                #            "specified max ",
+                #    "cmd_arg": [
+                #        "--max-repl-lag"
+                #    ],
+                #    "nargs": 1
+                #},
                     {
                     "name": "username",
                     "type" : "optional",
